@@ -161,7 +161,10 @@ class CameraCalibration(RequestCall):
         if camera_type == CameraType.KANNALA:
             assert self.undistortion_coefficients is not None
 
-    def to_dict(self) -> Dict:
+    def to_dict(self, by_alias: bool = False) -> Dict:
+        if by_alias:
+            # This param exists for API compat with the newer pydantic models.
+            raise Exception("by_alias can not be used with legacy calibrations")
         base = {
             "position": self.position.to_dict(),
             "rotation_quaternion": self.rotation_quaternion.to_dict(),
