@@ -2,4 +2,4 @@ from annotell.input_api.model.base_serializer import BaseSerializer
 
 
 class InitializedInput(BaseSerializer):
-    internal_id: str
+    scene_uuid: str
